"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  ActType: () => ActType,
  ArgFlag: () => ArgFlag,
  MemeAPI: () => MemeAPI,
  MemeError: () => MemeError,
  MemeTypes: () => types_exports
});
module.exports = __toCommonJS(src_exports);

// src/error.ts
var import_plugin_http = require("@cordisjs/plugin-http");
var MemeError = class _MemeError extends Error {
  constructor(type, response) {
    super(
      `(${response.status}) [${type ?? "unknown-error"}] ${_MemeError.formatMessage(response)}`
    );
    this.type = type;
    this.response = response;
    this.name = "MemeGeneratorError";
  }
  static {
    __name(this, "MemeError");
  }
  get memeMessage() {
    return _MemeError.formatMessage(this.response);
  }
};
((MemeError2) => {
  MemeError2.types = [
    "no-such-meme",
    "text-over-length",
    "open-image-failed",
    "params-mismatch",
    "image-number-mismatch",
    "text-number-mismatch",
    "text-or-name-not-enough",
    "arg-mismatch",
    "arg-parser-mismatch",
    "arg-model-mismatch",
    "meme-feedback"
  ];
  MemeError2.codeCond = {
    "no-such-meme": 531,
    "text-over-length": 532,
    "open-image-failed": 533,
    "image-number-mismatch": 541,
    "text-number-mismatch": 542,
    "text-or-name-not-enough": 543,
    "params-mismatch": [540, 549],
    "arg-parser-mismatch": 551,
    "arg-model-mismatch": 552,
    "arg-mismatch": [550, 559],
    "meme-feedback": [560, 569]
  };
  function formatMessage(response) {
    const {
      data: { detail }
    } = response;
    return typeof detail === "string" ? detail : detail.map(
      ({ type, loc, msg, input }) => `${loc.join(".")} [type=${type}, input=${input}]: ${msg}`
    ).join("\n");
  }
  MemeError2.formatMessage = formatMessage;
  __name(formatMessage, "formatMessage");
  function getTypeFromCode(code) {
    const entries = Object.entries(MemeError2.codeCond);
    for (const [type, cond] of entries) {
      if (Array.isArray(cond)) {
        if (code >= cond[0] && code <= cond[1]) return type;
      } else if (code === cond) {
        return type;
      }
    }
  }
  MemeError2.getTypeFromCode = getTypeFromCode;
  __name(getTypeFromCode, "getTypeFromCode");
  function constructFromHTTPError(error) {
    const { response } = error;
    if (!response || !("detail" in response.data)) return void 0;
    const errResp = response;
    const type = getTypeFromCode(errResp.status);
    return new MemeError2(type, errResp);
  }
  MemeError2.constructFromHTTPError = constructFromHTTPError;
  __name(constructFromHTTPError, "constructFromHTTPError");
  function promiseCatchHandler(e) {
    if (import_plugin_http.HTTP.Error.is(e)) {
      const memeError = constructFromHTTPError(e);
      if (memeError) throw memeError;
    }
    throw e;
  }
  MemeError2.promiseCatchHandler = promiseCatchHandler;
  __name(promiseCatchHandler, "promiseCatchHandler");
  async function catchWrapper(func) {
    try {
      return await func();
    } catch (e) {
      MemeError2.promiseCatchHandler(e);
    }
  }
  MemeError2.catchWrapper = catchWrapper;
  __name(catchWrapper, "catchWrapper");
})(MemeError || (MemeError = {}));

// src/api.ts
async function reqCatchWrapper(fn) {
  return (await MemeError.catchWrapper(fn)).data;
}
__name(reqCatchWrapper, "reqCatchWrapper");
var MemeAPI = class {
  // public options: Required<MemeAPI.Options>
  constructor(http) {
    this.http = http;
  }
  static {
    __name(this, "MemeAPI");
  }
  async renderList(data) {
    return reqCatchWrapper(
      () => this.http("/memes/render_list", { method: "POST", responseType: "blob", data })
    );
  }
  async getKeys() {
    return reqCatchWrapper(
      () => this.http("/memes/keys", { method: "GET", responseType: "json" })
    );
  }
  async getInfo(key) {
    return reqCatchWrapper(
      () => this.http(`/memes/${key}/info`, { method: "GET", responseType: "json" })
    );
  }
  async renderPreview(key) {
    return reqCatchWrapper(
      () => this.http(`/memes/${key}/preview`, { method: "GET", responseType: "blob" })
    );
  }
  async renderMeme(key, options) {
    const { images, texts, args } = options || {};
    const data = new FormData();
    images?.forEach((image) => data.append("images", image));
    texts?.forEach((text) => data.append("texts", text));
    if (args) data.append("args", JSON.stringify(args));
    return reqCatchWrapper(
      () => this.http(`/memes/${key}/`, { method: "POST", responseType: "blob", data })
    );
  }
};

// src/types.ts
var types_exports = {};
__export(types_exports, {
  ActType: () => ActType,
  ArgFlag: () => ArgFlag
});
var ActType = /* @__PURE__ */ ((ActType2) => {
  ActType2[ActType2["STORE"] = 0] = "STORE";
  ActType2[ActType2["APPEND"] = 1] = "APPEND";
  ActType2[ActType2["COUNT"] = 2] = "COUNT";
  return ActType2;
})(ActType || {});
var ArgFlag = /* @__PURE__ */ ((ArgFlag2) => {
  ArgFlag2["OPTIONAL"] = "?";
  ArgFlag2["HIDDEN"] = "/";
  ArgFlag2["ANTI"] = "!";
  return ArgFlag2;
})(ArgFlag || {});
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  ActType,
  ArgFlag,
  MemeAPI,
  MemeError,
  MemeTypes
});
