export declare enum ActType {
    STORE = 0,
    APPEND = 1,
    COUNT = 2
}
export interface Action {
    type: ActType;
    value: any;
}
export declare enum ArgFlag {
    OPTIONAL = "?",
    HIDDEN = "/",
    ANTI = "!"
}
export type UserInfoGender = 'male' | 'female' | 'unknown';
export interface UserInfo {
    name?: string;
    gender?: UserInfoGender;
}
export interface ParserArg {
    name: string;
    value: string;
    default?: any | null;
    flags?: ArgFlag[] | null;
}
export interface ParserOption {
    names: string[];
    args?: ParserArg[] | null;
    dest?: string | null;
    default?: any | null;
    action?: Action | null;
    help_text?: string | null;
    compact?: boolean | null;
}
export interface CommandShortcut {
    key: string;
    args?: string[] | null;
    humanized?: string | null;
}
export interface MemeArgsResponse {
    args_model: Record<string, any>;
    args_examples: Record<string, any>[];
    parser_options: ParserOption[];
}
export interface MemeParamsResponse {
    min_images: number;
    max_images: number;
    min_texts: number;
    max_texts: number;
    default_texts: string[];
    args_type?: MemeArgsResponse | null;
}
export interface MemeInfoResponse {
    key: string;
    params_type: MemeParamsResponse;
    keywords: string[];
    shortcuts: CommandShortcut[];
    tags: string[];
    date_created: string;
    date_modified: string;
}
export type MemeKeyWithPropertiesLabel = 'new' | 'hot';
export interface MemeKeyWithProperties {
    meme_key: string;
    disabled?: boolean;
    labels?: MemeKeyWithPropertiesLabel[];
}
export interface RenderMemeListRequest {
    meme_list?: MemeKeyWithProperties[];
    text_template?: string;
    add_category_icon?: boolean;
}
export interface PyDanticErrorDetails {
    type: string;
    loc: (string | number)[];
    msg: string;
    input: any;
    ctx?: Record<string, any>;
}
export interface MemeErrorResponse {
    detail: PyDanticErrorDetails[] | string;
}
